@@ -32,7 +32,6 @@ from .. import utils
 from ..types import FastEnum, SourceRef
 from .._exceptions import CASCacheError
 
-from .casdprocessmanager import CASDProcessManager
 from .casremote import CASRemote, _CASBatchRead, _CASBatchUpdate, BlobNotFound
 
 _BUFFER_SIZE = 65536
@@ -52,45 +51,22 @@ class CASLogLevel(FastEnum):
 #
 # Args:
 #     path (str): The root directory for the CAS repository
-#     casd (bool): True to spawn buildbox-casd (default) or False (testing only)
-#     cache_quota (int): User configured cache quota
-#     protect_session_blobs (bool): Disable expiry for blobs used in the current session
-#     log_level (LogLevel): Log level to give to buildbox-casd for logging
-#     log_directory (str): the root of the directory in which to store logs
+#     casd (CASDProcessManager): The buildbox-casd manager
+#     remote_cache (bool): True if a CAS server is configured as a remote cache (storage-service)
 #
 class CASCache:
-    def __init__(
-        self,
-        path,
-        *,
-        casd=True,
-        cache_quota=None,
-        remote_cache_spec=None,
-        protect_session_blobs=True,
-        log_level=CASLogLevel.WARNING,
-        log_directory=None,
-        messenger=None
-    ):
+    def __init__(self, path, *, casd, remote_cache=False):
         self.casdir = os.path.join(path, "cas")
         self.tmpdir = os.path.join(path, "tmp")
         os.makedirs(self.tmpdir, exist_ok=True)
 
         self._cache_usage_monitor = None
-        self._cache_usage_monitor_forbidden = False
 
-        self._remote_cache = bool(remote_cache_spec)
+        self._remote_cache = remote_cache
 
-        self._casd_process_manager = None
-        self._casd_channel = None
+        self._casd = casd
         if casd:
-            assert log_directory is not None, "log_directory is required when casd is True"
-            log_dir = os.path.join(log_directory, "_casd")
-            self._casd_process_manager = CASDProcessManager(
-                path, log_dir, log_level, cache_quota, remote_cache_spec, protect_session_blobs, messenger
-            )
-
-            self._casd_channel = self._casd_process_manager.create_channel()
-            self._cache_usage_monitor = _CASCacheUsageMonitor(self._casd_channel)
+            self._cache_usage_monitor = _CASCacheUsageMonitor(self._casd)
             self._cache_usage_monitor.start()
         else:
             assert not self._remote_cache
@@ -103,16 +79,16 @@ class CASCache:
     # Return ContentAddressableStorage stub for buildbox-casd channel.
     #
     def get_cas(self):
-        assert self._casd_channel, "CASCache was created without a channel"
-        return self._casd_channel.get_cas()
+        assert self._casd, "CASCache was created without buildbox-casd"
+        return self._casd.get_cas()
 
     # get_local_cas():
     #
     # Return LocalCAS stub for buildbox-casd channel.
     #
     def get_local_cas(self):
-        assert self._casd_channel, "CASCache was created without a channel"
-        return self._casd_channel.get_local_cas()
+        assert self._casd, "CASCache was created without buildbox-casd"
+        return self._casd.get_local_cas()
 
     # preflight():
     #
@@ -122,31 +98,15 @@ class CASCache:
         if not os.path.join(self.casdir, "objects"):
             raise CASCacheError("CAS repository check failed for '{}'".format(self.casdir))
 
-    # close_grpc_channels():
-    #
-    # Close the casd channel if it exists
-    #
-    def close_grpc_channels(self):
-        if self._casd_channel:
-            self._casd_channel.close()
-
     # release_resources():
     #
     # Release resources used by CASCache.
     #
-    def release_resources(self, messenger=None):
-        if self._casd_channel:
-            self._casd_channel.request_shutdown()
-
+    def release_resources(self):
         if self._cache_usage_monitor:
             self._cache_usage_monitor.stop()
             self._cache_usage_monitor.join()
 
-        if self._casd_process_manager:
-            self.close_grpc_channels()
-            self._casd_process_manager.release_resources(messenger)
-            self._casd_process_manager = None
-
     def get_default_remote(self):
         return self._default_remote
 
@@ -164,16 +124,15 @@ class CASCache:
 
     # contains_directory():
     #
-    # Check whether the specified directory and subdirectories are in the cache,
-    # i.e non dangling.
+    # Check whether the specified directory, subdirectories and files are in the
+    # cache, i.e non dangling.
     #
     # Args:
     #     digest (Digest): The directory digest to check
-    #     with_files (bool): Whether to check files as well
     #
     # Returns: True if the directory is available in the local cache
     #
-    def contains_directory(self, digest, *, with_files):
+    def contains_directory(self, digest):
         local_cas = self.get_local_cas()
 
         # Without a remote cache, `FetchTree` simply checks the local cache.
@@ -181,7 +140,7 @@ class CASCache:
         request.root_digest.CopyFrom(digest)
         # Always fetch Directory protos as they are needed to enumerate subdirectories and files.
         # Don't implicitly fetch file blobs from the remote cache as we don't need them.
-        request.fetch_file_blobs = with_files and not self._remote_cache
+        request.fetch_file_blobs = not self._remote_cache
 
         try:
             local_cas.FetchTree(request)
@@ -194,9 +153,20 @@ class CASCache:
                 raise CASCacheError("Unsupported buildbox-casd version: FetchTree unimplemented") from e
             raise
 
-        # Check whether everything is available in the remote cache.
-        missing_blobs = self.missing_blobs_for_directory(digest, remote=self._default_remote)
-        return not missing_blobs
+        # Make sure everything is available in the remote cache (storage-service)
+        request = local_cas_pb2.UploadTreeRequest()
+        request.root_digest.CopyFrom(digest)
+        try:
+            local_cas.UploadTree(request)
+            return True
+        except grpc.RpcError as e:
+            if e.code() == grpc.StatusCode.NOT_FOUND:
+                return False
+            if e.code() == grpc.StatusCode.UNIMPLEMENTED:
+                # Fallback path if buildbox-casd is too old to support UploadTree
+                missing_blobs = self.missing_blobs_for_directory(digest, remote=self._default_remote)
+                return not missing_blobs
+            raise
 
     # checkout():
     #
@@ -208,15 +178,9 @@ class CASCache:
     #     can_link (bool): Whether we can create hard links in the destination
     #
     def checkout(self, dest, tree, *, can_link=False, _fetch=True):
-        if _fetch and self._remote_cache:
+        if _fetch:
             # We need the files in the local cache
-            local_cas = self.get_local_cas()
-
-            request = local_cas_pb2.FetchTreeRequest()
-            request.root_digest.CopyFrom(tree)
-            request.fetch_file_blobs = True
-
-            local_cas.FetchTree(request)
+            self.ensure_tree(tree)
 
         os.makedirs(dest, exist_ok=True)
 
@@ -262,6 +226,57 @@ class CASCache:
             fullpath = os.path.join(dest, symlinknode.name)
             os.symlink(symlinknode.target, fullpath)
 
+    # ensure_tree():
+    #
+    # Make sure all blobs referenced by the given directory tree are available
+    # in the local cache when using a remote cache.
+    #
+    # Args:
+    #     tree (Digest): The digest of the tree
+    #
+    def ensure_tree(self, tree):
+        if self._remote_cache:
+            local_cas = self.get_local_cas()
+
+            request = local_cas_pb2.FetchTreeRequest()
+            request.root_digest.CopyFrom(tree)
+            request.fetch_file_blobs = True
+
+            local_cas.FetchTree(request)
+
+    # fetch_directory():
+    #
+    # Fetches remote directory and adds it to content addressable store.
+    #
+    # This recursively fetches directory objects and files.
+    #
+    # Args:
+    #     remote (Remote): The remote to use.
+    #     dir_digest (Digest): Digest object for the directory to fetch.
+    #
+    def fetch_directory(self, remote, dir_digest):
+        local_cas = self.get_local_cas()
+
+        request = local_cas_pb2.FetchTreeRequest()
+        request.instance_name = remote.local_cas_instance_name
+        request.root_digest.CopyFrom(dir_digest)
+        request.fetch_file_blobs = False
+
+        try:
+            local_cas.FetchTree(request)
+        except grpc.RpcError as e:
+            if e.code() == grpc.StatusCode.NOT_FOUND:
+                raise BlobNotFound(
+                    dir_digest.hash,
+                    "Failed to fetch directory tree {}: {}: {}".format(dir_digest.hash, e.code().name, e.details()),
+                ) from e
+            raise CASCacheError(
+                "Failed to fetch directory tree {}: {}: {}".format(dir_digest.hash, e.code().name, e.details())
+            ) from e
+
+        required_blobs = self.required_blobs_for_directory(dir_digest)
+        self.fetch_blobs(remote, required_blobs)
+
     # pull_tree():
     #
     # Pull a single Tree rather than a ref.
@@ -596,39 +611,6 @@ class CASCache:
             os.chmod(f.name, stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH)
             yield f
 
-    # _fetch_directory():
-    #
-    # Fetches remote directory and adds it to content addressable store.
-    #
-    # This recursively fetches directory objects and files.
-    #
-    # Args:
-    #     remote (Remote): The remote to use.
-    #     dir_digest (Digest): Digest object for the directory to fetch.
-    #
-    def _fetch_directory(self, remote, dir_digest):
-        local_cas = self.get_local_cas()
-
-        request = local_cas_pb2.FetchTreeRequest()
-        request.instance_name = remote.local_cas_instance_name
-        request.root_digest.CopyFrom(dir_digest)
-        request.fetch_file_blobs = False
-
-        try:
-            local_cas.FetchTree(request)
-        except grpc.RpcError as e:
-            if e.code() == grpc.StatusCode.NOT_FOUND:
-                raise BlobNotFound(
-                    dir_digest.hash,
-                    "Failed to fetch directory tree {}: {}: {}".format(dir_digest.hash, e.code().name, e.details()),
-                ) from e
-            raise CASCacheError(
-                "Failed to fetch directory tree {}: {}: {}".format(dir_digest.hash, e.code().name, e.details())
-            ) from e
-
-        required_blobs = self.required_blobs_for_directory(dir_digest)
-        self.fetch_blobs(remote, required_blobs)
-
     def _fetch_tree(self, remote, digest):
         self.fetch_blobs(remote, [digest])
 
@@ -730,19 +712,18 @@ class CASCache:
     #     (CASCacheUsage): The current status
     #
     def get_cache_usage(self):
-        assert not self._cache_usage_monitor_forbidden
         return self._cache_usage_monitor.get_cache_usage()
 
-    # get_casd_process_manager()
+    # get_casd()
     #
     # Get the underlying buildbox-casd process
     #
     # Returns:
     #   (subprocess.Process): The casd process that is used for the current cascache
     #
-    def get_casd_process_manager(self):
-        assert self._casd_process_manager is not None, "Only call this with a running buildbox-casd process"
-        return self._casd_process_manager
+    def get_casd(self):
+        assert self._casd is not None, "Only call this with a running buildbox-casd process"
+        return self._casd
 
 
 # _CASCacheUsage
@@ -783,9 +764,9 @@ class _CASCacheUsage:
 # buildbox-casd.
 #
 class _CASCacheUsageMonitor(threading.Thread):
-    def __init__(self, connection):
+    def __init__(self, casd):
         super().__init__()
-        self._connection = connection
+        self._casd = casd
         self._disk_usage = None
         self._disk_quota = None
         self._should_stop = False
@@ -797,7 +778,7 @@ class _CASCacheUsageMonitor(threading.Thread):
         self._should_stop = True
 
     def run(self):
-        local_cas = self._connection.get_local_cas()
+        local_cas = self._casd.get_local_cas()
 
         while not self._should_stop:
             try:
