@@ -68,9 +68,11 @@ class RemoteSpec:
         url: str,
         *,
         push: bool = False,
-        server_cert: str = None,
-        client_key: str = None,
-        client_cert: str = None,
+        server_cert: Optional[str] = None,
+        client_key: Optional[str] = None,
+        client_cert: Optional[str] = None,
+        access_token: Optional[str] = None,
+        access_token_reload_interval: Optional[int] = None,
         instance_name: Optional[str] = None,
         connection_config: Optional[MappingNode] = None,
         spec_node: Optional[MappingNode] = None,
@@ -96,6 +98,8 @@ class RemoteSpec:
         self.server_cert_file: Optional[str] = server_cert
         self.client_key_file: Optional[str] = client_key
         self.client_cert_file: Optional[str] = client_cert
+        self.access_token_file: Optional[str] = access_token
+        self.access_token_reload_interval: Optional[int] = access_token_reload_interval
 
         #
         # Private members
@@ -133,6 +137,8 @@ class RemoteSpec:
                 self.server_cert_file,
                 self.client_key_file,
                 self.client_cert_file,
+                self.access_token_file,
+                self.access_token_reload_interval,
                 self.keepalive_time,
             )
         )
@@ -196,16 +202,6 @@ class RemoteSpec:
     def open_channel(self) -> Channel:
         url = urlparse(self.url)
 
-        # Assert port number for RE endpoints
-        #
-        if self.remote_type == RemoteType.ENDPOINT and not url.port:
-            message = (
-                "Remote execution endpoints must specify the port number, for example: http://buildservice:50051."
-            )
-            if self._spec_node:
-                message = "{}: {}".format(self._spec_node.get_provenance(), message)
-            raise RemoteError(message)
-
         if url.scheme == "http":
             channel = grpc.insecure_channel("{}:{}".format(url.hostname, url.port or 80))
         elif url.scheme == "https":
@@ -218,6 +214,27 @@ class RemoteSpec:
 
         return channel
 
+    # to_localcas_remote()
+    #
+    # Create a `LocalContentAddressableStorage.Remote` proto from the `RemoteSpec` object.
+    #
+    def to_localcas_remote(self, remote):
+        remote.url = self.url
+        if self.instance_name:
+            remote.instance_name = self.instance_name
+        if self.server_cert:
+            remote.server_cert = self.server_cert
+        if self.client_key:
+            remote.client_key = self.client_key
+        if self.client_cert:
+            remote.client_cert = self.client_cert
+        if self.access_token_file:
+            remote.access_token_path = self.access_token_file
+            if self.access_token_reload_interval is not None:
+                remote.access_token_reload_interval.FromSeconds(self.access_token_reload_interval * 60)
+        if self.keepalive_time is not None:
+            remote.keepalive_time.FromSeconds(self.keepalive_time)
+
     # new_from_node():
     #
     # Creates a RemoteSpec() from a YAML loaded node.
@@ -240,6 +257,8 @@ class RemoteSpec:
         server_cert: Optional[str] = None
         client_key: Optional[str] = None
         client_cert: Optional[str] = None
+        access_token: Optional[str] = None
+        access_token_reload_interval: Optional[int] = None
         push: bool = False
         remote_type: str = RemoteType.ENDPOINT
 
@@ -264,7 +283,9 @@ class RemoteSpec:
 
         auth_node = spec_node.get_mapping("auth", None)
         if auth_node:
-            server_cert, client_key, client_cert = cls._parse_auth(auth_node, basedir)
+            server_cert, client_key, client_cert, access_token, access_token_reload_interval = cls._parse_auth(
+                auth_node, basedir
+            )
 
         connection_config = spec_node.get_mapping("connection-config", None)
 
@@ -275,6 +296,8 @@ class RemoteSpec:
             server_cert=server_cert,
             client_key=client_key,
             client_cert=client_cert,
+            access_token=access_token,
+            access_token_reload_interval=access_token_reload_interval,
             instance_name=instance_name,
             connection_config=connection_config,
             spec_node=spec_node,
@@ -306,6 +329,7 @@ class RemoteSpec:
         server_cert: Optional[str] = None
         client_key: Optional[str] = None
         client_cert: Optional[str] = None
+        access_token: Optional[str] = None
 
         if purpose == RemoteSpecPurpose.PULL:
             push = False
@@ -354,6 +378,8 @@ class RemoteSpec:
                     client_key = cls._resolve_path(val, os.getcwd())
                 elif key == "client-cert":
                     client_cert = cls._resolve_path(val, os.getcwd())
+                elif key == "access-token":
+                    access_token = cls._resolve_path(val, os.getcwd())
                 else:
                     raise RemoteError("Unexpected key '{}' encountered".format(key))
         else:
@@ -370,6 +396,7 @@ class RemoteSpec:
             server_cert=server_cert,
             client_key=client_key,
             client_cert=client_cert,
+            access_token=access_token,
             instance_name=instance_name,
         )
 
@@ -400,27 +427,34 @@ class RemoteSpec:
     #    basedir: The base directory which cert files are relative to, or None
     #
     # Returns:
-    #    A 3 tuple containing the filenames for the server-cert,
-    #    the client-key and the client-cert
+    #    A 5 tuple containing the filenames for the server-cert, the client-key,
+    #    the client-cert, the access-token and the access-token-reload-interval
     #
     @classmethod
     def _parse_auth(
         cls, auth_node: MappingNode, basedir: Optional[str] = None
-    ) -> Tuple[Optional[str], Optional[str], Optional[str]]:
+    ) -> Tuple[Optional[str], Optional[str], Optional[str], Optional[str], Optional[int]]:
 
-        auth_keys = ["server-cert", "client-key", "client-cert"]
+        auth_path_keys = ["server-cert", "client-key", "client-cert", "access-token"]
+        auth_int_keys = ["access-token-reload-interval"]
         auth_values = {}
-        auth_node.validate_keys(auth_keys)
+        auth_int_values = {}
+        auth_node.validate_keys(auth_path_keys + auth_int_keys)
 
-        for key in auth_keys:
+        for key in auth_path_keys:
             value = auth_node.get_str(key, None)
             if value:
                 value = cls._resolve_path(value, basedir)
             auth_values[key] = value
 
+        for key in auth_int_keys:
+            auth_int_values[key] = auth_node.get_int(key, None)
+
         server_cert = auth_values["server-cert"]
         client_key = auth_values["client-key"]
         client_cert = auth_values["client-cert"]
+        access_token = auth_values["access-token"]
+        access_token_reload_interval = auth_int_values["access-token-reload-interval"]
 
         if client_key and not client_cert:
             provenance = auth_node.get_node("client-key").get_provenance()
@@ -434,7 +468,7 @@ class RemoteSpec:
                 "{}: 'client-cert' was specified without 'client-key'".format(provenance), LoadErrorReason.INVALID_DATA
             )
 
-        return server_cert, client_key, client_cert
+        return server_cert, client_key, client_cert, access_token, access_token_reload_interval
 
     # _load_credential_files():
     #
