@@ -127,8 +127,6 @@ class Stream:
     def set_project(self, project):
         assert self._project is None
         self._project = project
-        if self._project:
-            self._project.load_context.set_fetch_subprojects(self._fetch_subprojects)
 
     # load_selection()
     #
@@ -147,6 +145,7 @@ class Stream:
     #    source_remotes: Source cache remotes specified on the commmand line
     #    ignore_project_artifact_remotes: Whether to ignore artifact remotes specified by projects
     #    ignore_project_source_remotes: Whether to ignore source remotes specified by projects
+    #    need_state: Whether resolving element state is required
     #
     # Returns:
     #    (list of Element): The selected elements
@@ -163,6 +162,7 @@ class Stream:
         source_remotes: Iterable[RemoteSpec] = (),
         ignore_project_artifact_remotes: bool = False,
         ignore_project_source_remotes: bool = False,
+        need_state: bool = True,
     ):
         with PROFILER.profile(Topics.LOAD_SELECTION, "_".join(t.replace(os.sep, "-") for t in targets)):
             target_objects = self._load(
@@ -176,6 +176,7 @@ class Stream:
                 source_remotes=source_remotes,
                 ignore_project_artifact_remotes=ignore_project_artifact_remotes,
                 ignore_project_source_remotes=ignore_project_source_remotes,
+                need_state=need_state,
             )
             return target_objects
 
@@ -189,13 +190,16 @@ class Stream:
     #    sources_of_cached_elements (bool): True to query the source cache for elements with a cached artifact
     #    only_sources (bool): True to only query the source cache
     #
-    def query_cache(self, elements, *, sources_of_cached_elements=False, only_sources=False):
+    def query_cache(self, elements, *, sources_of_cached_elements=False, only_sources=False, need_state=False):
         # It doesn't make sense to combine these flags
         assert not sources_of_cached_elements or not only_sources
 
         with self._context.messenger.simple_task("Query cache", silent_nested=True) as task:
-            # Enqueue complete build plan as this is required to determine `buildable` status.
-            plan = list(_pipeline.dependencies(elements, _Scope.ALL))
+            if need_state:
+                # Enqueue complete build plan as this is required to determine `buildable` status.
+                plan = list(_pipeline.dependencies(elements, _Scope.ALL))
+            else:
+                plan = elements
 
             if self._context.remote_cache_spec:
                 # Parallelize cache queries if a remote cache is configured
@@ -1320,6 +1324,22 @@ class Stream:
         assert queue
         queue.enqueue([element])
 
+    # fetch_subprojects()
+    #
+    # Fetch subprojects as part of the project and element loading process.
+    #
+    # This is passed to the Project in order to handle loading of subprojects
+    #
+    # Args:
+    #    junctions (list of Element): The junctions to fetch
+    #
+    def fetch_subprojects(self, junctions):
+        self._reset()
+        queue = FetchQueue(self._scheduler)
+        queue.enqueue(junctions)
+        self.queues = [queue]
+        self._run()
+
     #############################################################
     #                    Private Methods                        #
     #############################################################
@@ -1340,20 +1360,6 @@ class Stream:
                 message, detail="No project.conf or active workspace was located", reason="project-not-loaded"
             )
 
-    # _fetch_subprojects()
-    #
-    # Fetch subprojects as part of the project and element loading process.
-    #
-    # Args:
-    #    junctions (list of Element): The junctions to fetch
-    #
-    def _fetch_subprojects(self, junctions):
-        self._reset()
-        queue = FetchQueue(self._scheduler)
-        queue.enqueue(junctions)
-        self.queues = [queue]
-        self._run()
-
     # _load_artifacts()
     #
     # Loads artifacts from target artifact refs
@@ -1617,6 +1623,7 @@ class Stream:
     #    source_remotes: Source cache remotes specified on the commmand line
     #    ignore_project_artifact_remotes: Whether to ignore artifact remotes specified by projects
     #    ignore_project_source_remotes: Whether to ignore source remotes specified by projects
+    #    need_state: Whether resolving element state is required
     #
     # Returns:
     #    (list of Element): The primary element selection
@@ -1637,6 +1644,7 @@ class Stream:
         source_remotes: Iterable[RemoteSpec] = (),
         ignore_project_artifact_remotes: bool = False,
         ignore_project_source_remotes: bool = False,
+        need_state: bool = True,
     ):
         elements, except_elements, artifacts = self._load_elements_from_targets(
             targets, except_targets, rewritable=False, valid_artifact_names=load_artifacts
@@ -1656,14 +1664,15 @@ class Stream:
         self.targets = elements
 
         # Connect to remote caches, this needs to be done before resolving element state
-        self._context.initialize_remotes(
-            connect_artifact_cache,
-            connect_source_cache,
-            artifact_remotes,
-            source_remotes,
-            ignore_project_artifact_remotes=ignore_project_artifact_remotes,
-            ignore_project_source_remotes=ignore_project_source_remotes,
-        )
+        if need_state:
+            self._context.initialize_remotes(
+                connect_artifact_cache,
+                connect_source_cache,
+                artifact_remotes,
+                source_remotes,
+                ignore_project_artifact_remotes=ignore_project_artifact_remotes,
+                ignore_project_source_remotes=ignore_project_source_remotes,
+            )
 
         # In some cases we need to have an actualized artifact, with all of
         # it's metadata, such that we can derive attributes about the artifact
@@ -1799,7 +1808,7 @@ class Stream:
             self._session_start_callback()
 
         self._running = True
-        status = self._scheduler.run(self.queues, self._context.get_cascache().get_casd_process_manager())
+        status = self._scheduler.run(self.queues, self._context.get_cascache().get_casd())
         self._running = False
 
         if status == SchedStatus.ERROR:
