@@ -349,14 +349,6 @@ class Cli:
             if env is not None:
                 stack.enter_context(environment(env))
 
-            # Ensure we have a working stdout - required to work
-            # around a bug that appears to cause AIX to close
-            # sys.__stdout__ after setup.py
-            try:
-                sys.__stdout__.fileno()
-            except ValueError:
-                sys.__stdout__ = open("/dev/stdout", "w", encoding="utf-8")  # pylint: disable=consider-using-with
-
             result = self._invoke(bst_cli, bst_args, binary_capture=binary_capture)
 
         # Some informative stdout we can observe when anything fails
@@ -549,7 +541,7 @@ class CliIntegration(Cli):
 
                 temp_project = os.path.join(scratchdir, "project.conf")
                 with open(temp_project, "w", encoding="utf-8") as f:
-                    yaml.safe_dump(project_config, f)
+                    _yaml.roundtrip_dump(project_config, f)
 
                 project_config = _yaml.load(temp_project, shortname="project.conf")
 
@@ -703,6 +695,7 @@ class TestArtifact:
             yield None
         else:
             if str(artifact.buildtree):
+                # pylint: disable-next=contextmanager-generator-missing-cleanup
                 with self._extract_subdirectory(tmpdir, artifact.buildtree) as f:
                     yield f
             else:
@@ -725,7 +718,7 @@ class TestArtifact:
     def _extract_subdirectory(self, tmpdir, digest):
         with tempfile.TemporaryDirectory() as extractdir:
             try:
-                cas = CASCache(str(tmpdir), casd=False)
+                cas = CASCache(str(tmpdir), casd=None)
                 cas.checkout(extractdir, digest)
                 yield extractdir
             except FileNotFoundError:
