@@ -512,7 +512,7 @@ class Source(Plugin):
         """
         raise ImplError("Source plugin '{}' does not implement set_ref()".format(self.get_kind()))
 
-    def track(self, *, previous_sources_dir: str = None) -> SourceRef:
+    def track(self, *, previous_sources_dir: Optional[str] = None) -> SourceRef:
         """Resolve a new ref from the plugin's track option
 
         Args:
@@ -539,7 +539,7 @@ class Source(Plugin):
         # Allow a non implementation
         return None
 
-    def fetch(self, *, previous_sources_dir: str = None) -> None:
+    def fetch(self, *, previous_sources_dir: Optional[str] = None) -> None:
         """Fetch remote sources and mirror them locally, ensuring at least
         that the specific reference is cached locally.
 
@@ -765,6 +765,9 @@ class Source(Plugin):
             elif alias_override is not None:
                 override_subst = alias_override
 
+            else:
+                assert False, "unreachable"
+
             # The default source mirror will give prefix URLs
             if isinstance(override_subst._mirror, str):
                 return override_subst._mirror + url_body
@@ -1060,7 +1063,7 @@ class Source(Plugin):
 
         def do_load_ref(node):
             try:
-                self.load_ref(ref_node)
+                self.load_ref(node)
             except ImplError as e:
                 raise SourceError(
                     "{}: Storing refs in project.refs is not supported by '{}' sources".format(self, self.get_kind()),
@@ -1260,7 +1263,7 @@ class Source(Plugin):
     # Args:
     #   previous_sources_dir (str): directory where previous sources are staged
     #
-    def _track(self, previous_sources_dir: str = None) -> SourceRef:
+    def _track(self, previous_sources_dir: Optional[str] = None) -> SourceRef:
         if self.BST_REQUIRES_PREVIOUS_SOURCES_TRACK:
             new_ref = self.__do_track(previous_sources_dir=previous_sources_dir)
         else:
