@@ -609,6 +609,10 @@ def test_build_checkout_tarball_links(datafiles, cli):
     result.assert_success()
 
     with tarfile.open(name=checkout, mode="r:") as tar:
+        # This tarball is generated by the above `bst artifact checkout`, so there is no security concern.
+        # Use the `tar` extraction filter if available (upstream Python 3.12+) for consistent behavior with
+        # future Python versions and as safeguard against bugs in `bst artifact checkout`.
+        tar.extraction_filter = getattr(tarfile, "tar_filter", (lambda member, path: member))
         tar.extractall(extract)
 
     with open(os.path.join(extract, "basicfolder", "basicsymlink"), encoding="utf-8") as fp:
