@@ -16,7 +16,6 @@
 # pylint: disable=redefined-outer-name
 
 import os
-import glob
 from contextlib import ExitStack
 import pytest
 
@@ -253,6 +252,86 @@ def test_host_tools_errors_are_not_cached(cli, datafiles, tmp_path):
     assert cli.get_element_state(project, "element.bst") == "cached"
 
 
+# Tests that failed builds will be retried if --retry-failed is specified
+#
+@pytest.mark.datafiles(DATA_DIR)
+@pytest.mark.skipif(not HAVE_SANDBOX, reason="Only available with a functioning sandbox")
+@pytest.mark.parametrize("use_share", (False, True), ids=["local-cache", "pull-failed-artifact"])
+@pytest.mark.parametrize("retry", (True, False), ids=["retry", "no-retry"])
+@pytest.mark.parametrize("strict", (True, False), ids=["strict", "non-strict"])
+def test_retry_failed(cli, tmpdir, datafiles, use_share, retry, strict):
+    project = str(datafiles)
+    target_path = os.path.join(project, "elements", "target.bst")
+
+    # Use separate cache directories for each iteration of this test
+    # even though we're using cli_integration
+    #
+    # Global nonstrict configuration ensures all commands will be non-strict
+    cli.configure({"cachedir": cli.directory, "projects": {"test": {"strict": strict}}})
+
+    def generate_target():
+        return {
+            "kind": "manual",
+            "depends": [
+                "base.bst",
+            ],
+            "config": {
+                "build-commands": [
+                    "test -e /foo",
+                ],
+            },
+        }
+
+    with ExitStack() as stack:
+
+        if use_share:
+            share = stack.enter_context(create_artifact_share(os.path.join(str(tmpdir), "artifactshare")))
+            cli.configure({"artifacts": {"servers": [{"url": share.repo, "push": True}]}})
+
+        target = generate_target()
+        _yaml.roundtrip_dump(target, target_path)
+
+        # Try to build it, this should result in caching a failure of the target
+        result = cli.run(project=project, args=["build", "target.bst"])
+        result.assert_main_error(ErrorDomain.STREAM, None)
+
+        # Assert that it's cached in a failed artifact
+        assert cli.get_element_state(project, "target.bst") == "failed"
+
+        if use_share:
+            # Delete the local cache, provoke pulling of the failed build
+            cli.remove_artifact_from_cache(project, "target.bst")
+
+            # Assert that the failed build has been removed
+            assert cli.get_element_state(project, "target.bst") == "buildable"
+
+        # Even though we are in non-strict mode, the failed build should be retried
+        if retry:
+            result = cli.run(project=project, args=["build", "--retry-failed", "target.bst"])
+        else:
+            result = cli.run(project=project, args=["build", "target.bst"])
+
+        # If we did not modify the cache key, we want to assert that we did not
+        # in fact attempt to rebuild the failed artifact.
+        #
+        # Since the UX is very similar, we'll distinguish this by counting the number of
+        # build logs which were produced.
+        #
+        result.assert_main_error(ErrorDomain.STREAM, None)
+        if retry:
+            assert "target.bst" in result.get_built_elements()
+            assert "target.bst" in result.get_discarded_elements()
+        else:
+            assert "target.bst" not in result.get_built_elements()
+            assert "target.bst" not in result.get_discarded_elements()
+
+        if use_share:
+            # Assert that we did indeed go through the motions of downloading the failed
+            # build, and possibly discarded the failed artifact if the strong key did not match
+            #
+            assert "target.bst" in result.get_pulled_elements()
+
+
 # Tests that failed builds will be retried in strict mode when dependencies have changed.
 #
 # This test ensures:
@@ -263,8 +342,8 @@ def test_host_tools_errors_are_not_cached(cli, datafiles, tmp_path):
 @pytest.mark.datafiles(DATA_DIR)
 @pytest.mark.skipif(not HAVE_SANDBOX, reason="Only available with a functioning sandbox")
 @pytest.mark.parametrize("use_share", (False, True), ids=["local-cache", "pull-failed-artifact"])
-@pytest.mark.parametrize("retry", (True, False), ids=["retry", "no-retry"])
-def test_nonstrict_retry_failed(cli, tmpdir, datafiles, use_share, retry):
+@pytest.mark.parametrize("success", (True, False), ids=["success", "no-success"])
+def test_nonstrict_retry_failed(cli, tmpdir, datafiles, use_share, success):
     project = str(datafiles)
     intermediate_path = os.path.join(project, "elements", "intermediate.bst")
     dep_path = os.path.join(project, "elements", "dep.bst")
@@ -341,29 +420,22 @@ def test_nonstrict_retry_failed(cli, tmpdir, datafiles, use_share, retry):
             # Assert that the failed build has been removed
             assert cli.get_element_state(project, "target.bst") == "buildable"
 
-        # Regenerate the dependency so that the target would succeed to build, if the
-        # test is configured to test a retry
-        if retry:
+        # Regenerate the dependency so that the target would succeed to build
+        if success:
             dep = generate_dep("foo", "intermediate.bst")
             _yaml.roundtrip_dump(dep, dep_path)
 
         # Even though we are in non-strict mode, the failed build should be retried
         result = cli.run(project=project, args=["build", "target.bst"])
 
-        # If we did not modify the cache key, we want to assert that we did not
-        # in fact attempt to rebuild the failed artifact.
+        # Because the intermediate.bst is changed, the failed target.bst will be
+        # retried unconditionally, assert that it gets discarded.
         #
-        # Since the UX is very similar, we'll distinguish this by counting the number of
-        # build logs which were produced.
-        #
-        logdir = os.path.join(cli.directory, "logs", "test", "target")
-        build_logs = glob.glob("{}/*-build.*.log".format(logdir))
-        if retry:
+        assert "target.bst" in result.get_discarded_elements()
+        if success:
             result.assert_success()
-            assert len(build_logs) == 2
         else:
             result.assert_main_error(ErrorDomain.STREAM, None)
-            assert len(build_logs) == 1
 
         if use_share:
             # Assert that we did indeed go through the motions of downloading the failed
